@@ -3,7 +3,8 @@
 
 from .dev import wcat
 from .dev import googlebooks
-# from .dev import isbndb               # <-- HERE
+from .dev import merge
+# from .dev import isbndb              # <-- HERE
 
 """
 Registry for metadata services
@@ -11,5 +12,6 @@ Registry for metadata services
 services = {'default': wcat.query,   # <-- mandatory
             'wcat': wcat.query,
             'goob': googlebooks.query,
+            'merge': merge.query,
             #'isbndb': isbndb.query  # <-- HERE
             }
